==> tidyplots_0.2.0.tar.gz: tidyplots/R/data.R <==

#' RNA-Seq expression data
#' @format A data frame.
#' @source
#' [Bassoon proteinopathy drives neurodegeneration in multiple sclerosis](https://www.nature.com/articles/s41593-019-0385-4), Nature Neuroscience
#'
#' [GSE104899](https://www.ncbi.nlm.nih.gov/geo/query/acc.cgi?acc=GSE104899), Gene Expression Omnibus
#' @examples
#' dplyr::glimpse(gene_expression)
"gene_expression"

#' Time course data
#' @format A data frame.
#' @source
#' tidyplots package
#' @examples
#' dplyr::glimpse(time_course)
"time_course"

#' Energy data
#' @format A data frame.
#' @source
#' [Energy-Charts](https://www.energy-charts.info), Energy production data, Germany
#' @examples
#' dplyr::glimpse(energy)
"energy"

#' Energy week data
#' @format A data frame.
#' @source
#' [Energy-Charts](https://www.energy-charts.info), Energy production data, Germany
#' @examples
#' dplyr::glimpse(energy_week)
"energy_week"

#' Study data
#' @format A data frame.
#' @source
#' tidyplots package
#' @examples
#' dplyr::glimpse(study)
"study"

#' Animals data
#' @format A data frame.
#' @source
#' ChatGPT-3.5, *Caution: The accuracy of the data has not been verified.*
#' @examples
#' dplyr::glimpse(animals)
"animals"

#' Spending data
#' @format A data frame.
#' @source
#' tidyplots package
#' @examples
#' dplyr::glimpse(spendings)
"spendings"

#' Distributions data
#' @format A data frame.
#' @source
#' tidyplots package
#' @examples
#' dplyr::glimpse(distributions)
"distributions"

#' Dinosaurs data
#' @format A data frame.
#' @source
#' ChatGPT-3.5, *Caution: The accuracy of the data has not been verified.*
#' @examples
#' dplyr::glimpse(dinosaurs)
"dinosaurs"

#' EU countries data
#' @format A data frame.
#' @source
#' ChatGPT-3.5, *Caution: The accuracy of the data has not been verified.*
#' @examples
#' dplyr::glimpse(eu_countries)
"eu_countries"

#' Climate data
#' @format A data frame.
#' @source
#' [National Oceanic and Atmospheric Administration](https://www.noaa.gov), Temperature data, weather station Hamburg Fuhlsbüttel, Germany
#' @examples
#' dplyr::glimpse(climate)
"climate"

==> tidyplots_0.2.2.tar.gz: tidyplots/R/data.R <==

#' RNA-Seq expression data
#' @format A data frame.
#' @source
#' [Bassoon proteinopathy drives neurodegeneration in multiple sclerosis](https://www.nature.com/articles/s41593-019-0385-4), Nature Neuroscience
#'
#' [GSE104899](https://www.ncbi.nlm.nih.gov/geo/query/acc.cgi?acc=GSE104899), Gene Expression Omnibus
#' @examples
#' dplyr::glimpse(gene_expression)
"gene_expression"

#' Time course data
#' @format A data frame.
#' @source
#' tidyplots package
#' @examples
#' dplyr::glimpse(time_course)
"time_course"

#' Energy data
#' @format A data frame.
#' @source
#' [Energy-Charts](https://www.energy-charts.info), Energy production data, Germany
#' @examples
#' dplyr::glimpse(energy)
"energy"

#' Energy week data
#' @format A data frame.
#' @source
#' [Energy-Charts](https://www.energy-charts.info), Energy production data, Germany
#' @examples
#' dplyr::glimpse(energy_week)
"energy_week"

#' Study data
#' @format A data frame.
#' @source
#' tidyplots package
#' @examples
#' dplyr::glimpse(study)
"study"

#' Animals data
#' @format A data frame.
#' @source
#' ChatGPT-3.5, *Caution: The accuracy of the data has not been verified.*
#' @examples
#' dplyr::glimpse(animals)
"animals"

#' Spending data
#' @format A data frame.
#' @source
#' tidyplots package
#' @examples
#' dplyr::glimpse(spendings)
"spendings"

#' Distributions data
#' @format A data frame.
#' @source
#' tidyplots package
#' @examples
#' dplyr::glimpse(distributions)
"distributions"

#' Dinosaurs data
#' @format A data frame.
#' @source
#' ChatGPT-3.5, *Caution: The accuracy of the data has not been verified.*
#' @examples
#' dplyr::glimpse(dinosaurs)
"dinosaurs"

#' EU countries data
#' @format A data frame.
#' @source
#' ChatGPT-3.5, *Caution: The accuracy of the data has not been verified.*
#' @examples
#' dplyr::glimpse(eu_countries)
"eu_countries"

#' Climate data
#' @format A data frame.
#' @source
#' National Oceanic and Atmospheric Administration, Temperature data, weather station Hamburg Fuhlsbüttel, Germany
#' @examples
#' dplyr::glimpse(climate)
"climate"
